@@ -1,5 +1,6 @@
 import re
 from functools import cache
+from importlib import metadata
 from io import StringIO
 from pathlib import Path
 from typing import Sequence
@@ -16,6 +17,42 @@ from .settings import Settings, load_settings
 from .visitor import RefurbVisitor
 
 
+def usage() -> None:
+    print(
+        """\
+usage: refurb [--ignore err] [--load path] [--debug] [--quiet] src [srcs...]
+       refurb [--help | -h]
+       refurb [--version | -v]
+       refurb --explain err
+       refurb gen
+
+Command Line Options:
+
+-h, --help       This help menu.
+--version, -v    Print version information.
+--ignore err     Ignore an error. Can be repeated.
+--load module    Add a module to the list of paths to be searched when looking
+                 for checks. Can be repeated.
+--debug          Print the AST representation of all files that where checked.
+--quiet          Suppress default "--explain" suggestion when an error occurs.
+src              A file or folder.
+
+
+Subcommands:
+
+gen              Generate boilerplate code for a new check, meant for
+                 developers.
+"""
+    )
+
+
+def version() -> str:  # pragma: no cover
+    refurb_version = metadata.version("refurb")
+    mypy_version = metadata.version("mypy")
+
+    return f"Refurb: v{refurb_version}\nMypy: v{mypy_version}"
+
+
 @cache
 def get_source_lines(filepath: str) -> list[str]:
     return Path(filepath).read_text().splitlines()
@@ -97,6 +134,15 @@ def sort_errors(
     )
 
 
+def format_errors(errors: Sequence[Error | str], quiet: bool) -> str:
+    done = "\n".join((str(error) for error in errors))
+
+    if not quiet and any(isinstance(error, Error) for error in errors):
+        done += "\n\nRun `refurb --explain ERR` to further explain an error. Use `--quiet` to silence this message"  # noqa: E501
+
+    return done
+
+
 def main(args: list[str]) -> int:
     try:
         settings = load_settings(args)
@@ -105,6 +151,16 @@ def main(args: list[str]) -> int:
         print(e)
         return 1
 
+    if settings.help:
+        usage()
+
+        return 0
+
+    if settings.version:
+        print(version())
+
+        return 0
+
     if settings.generate:
         generate()
 
@@ -112,11 +168,12 @@ def main(args: list[str]) -> int:
 
     if settings.explain:
         print(explain(settings.explain, settings.load or []))
+
         return 0
 
     errors = run_refurb(settings)
 
-    for error in errors:
-        print(error)
+    if formatted_errors := format_errors(errors, settings.quiet):
+        print(formatted_errors)
 
     return 1 if errors else 0
