@@ -19,6 +19,9 @@ class Settings:
     load: list[str] | None = None
     debug: bool = False
     generate: bool = False
+    help: bool = False
+    version: bool = False
+    quiet: bool = False
 
 
 ERROR_ID_REGEX = re.compile("^([A-Z]{3,4})?(\\d{3})$")
@@ -42,14 +45,21 @@ def parse_config_file(contents: str) -> Settings:
                 parse_error_id(str(x)) for x in settings.get("ignore", [])
             )
 
-            return Settings(ignore=ignore or None, load=settings.get("load"))
+            return Settings(
+                ignore=ignore or None,
+                load=settings.get("load"),
+                quiet=settings.get("quiet", False),
+            )
 
     return Settings()
 
 
 def parse_command_line_args(args: list[str]) -> Settings:
-    if not args:
-        raise ValueError("refurb: no arguments passed")
+    if not args or args[0] in ("--help", "-h"):
+        return Settings(help=True)
+
+    if args[0] in ("--version", "-v"):
+        return Settings(version=True)
 
     if args[0] == "gen":
         return Settings(generate=True)
@@ -60,11 +70,15 @@ def parse_command_line_args(args: list[str]) -> Settings:
     load: list[str] = []
     explain: ErrorCode | None = None
     debug = False
+    quiet = False
 
     for arg in iargs:
         if arg == "--debug":
             debug = True
 
+        elif arg == "--quiet":
+            quiet = True
+
         elif arg == "--explain":
             value = next(iargs, None)
 
@@ -101,6 +115,7 @@ def parse_command_line_args(args: list[str]) -> Settings:
         load=load or None,
         debug=debug,
         explain=explain,
+        quiet=quiet,
     )
 
 
